@@ -38,6 +38,12 @@ __all__ = [
     "ConnectionTimeout",
     "AuthenticationException",
     "AuthorizationException",
+    "OpenSearchDslException",
+    "UnknownDslObject",
+    "ValidationException",
+    "IllegalOperation",
+    "OpenSearchWarning",
+    "OpenSearchDeprecationWarning",
 ]
 
 
@@ -163,6 +169,22 @@ class AuthorizationException(TransportError):
     """Exception representing a 403 status code."""
 
 
+class OpenSearchDslException(Exception):
+    """Base class for all OpenSearchDsl exceptions"""
+
+
+class UnknownDslObject(OpenSearchDslException):
+    """Exception representing UnknownDSLObject"""
+
+
+class ValidationException(ValueError, OpenSearchDslException):
+    """Exception representing Validation Error"""
+
+
+class IllegalOperation(OpenSearchDslException):
+    """Exception representing IllegalOperation"""
+
+
 class OpenSearchWarning(Warning):
     """Warning that is raised when a deprecated option
     or incorrect usage is flagged via the 'Warning' HTTP header.
