@@ -37,7 +37,7 @@ from opensearchpy.exceptions import ConnectionError
 if "OPENSEARCH_URL" in os.environ:
     OPENSEARCH_URL = os.environ["OPENSEARCH_URL"]
 else:
-    OPENSEARCH_URL = "https://elastic:changeme@localhost:9200"
+    OPENSEARCH_URL = "https://admin:admin@localhost:9200"
 
 
 def get_test_client(nowait=False, **kwargs):
@@ -108,5 +108,6 @@ if "OPENSEARCH_VERSION" in os.environ:
 else:
     client = OpenSearch(
         OPENSEARCH_URL,
+        verify_certs=False,
     )
     OPENSEARCH_VERSION = opensearch_version(client)
